package com.info666.app.infraredRemote;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.info666.app.infraredRemote.activity.InfraredRemoteActivity;
import com.info666.app.infraredRemote.activity.MyCaptureActivity;
import com.king.zxing.CameraScan;
import com.tencent.vasdolly.helper.ChannelReaderUtil;


import cn.hutool.http.HttpUtil;

public class MainActivity extends AppCompatActivity implements View.OnClickListener, Handler.Callback {

    private SharedPreferences sp;

    private EditText etUrl;

    private Button btnNext;

    private Handler handler;

    private boolean isDebug = false;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        sp = getSharedPreferences("config", Context.MODE_PRIVATE);
        //初始化试图
        this.initView();
        //初始化app参数
        this.initApp();
    }

    public void initView(){
        etUrl = findViewById(R.id.et_url);
        btnNext = findViewById(R.id.bt_next);
        btnNext.setOnClickListener(this);
        findViewById(R.id.bt_qrc).setOnClickListener(this);
        etUrl.setText(sp.getString("url","http://ccvadmin.info666.com/ljshxyqy/"));
        handler = new Handler(this);
        if(isDebug){
            findViewById(R.id.ll_welcome).setVisibility(View.GONE);
            findViewById(R.id.et_url).setVisibility(View.VISIBLE);
            findViewById(R.id.ll_mt).setVisibility(View.VISIBLE);
            findViewById(R.id.bt_next).setVisibility(View.VISIBLE);
            findViewById(R.id.bt_qrc).setVisibility(View.VISIBLE);
        }
    }

    public void initApp(){
        new Thread(()->{
            Message message = new Message();
            try {
                String result = HttpUtil.get("http://ykapi.sh-jh.cn/api/api/v1/appConfig/getAppConfig",10 * 1000);
                JSONObject jsonObject = JSONObject.parseObject(result);
                JSONArray jsonArray = jsonObject.getJSONArray("data");
                message.what = 200;
                message.obj = jsonArray.getJSONObject(0).toJSONString();
            }catch (Exception e){
                message.what = 500;
            }finally {
                handler.sendMessage(message);
            }


        }).start();
    }


    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.bt_next){
            String url = etUrl.getText().toString();
            if(null == url || url.length() == 0){
                return;
            }
            this.goInfraredRemote(url);
        } else if(v.getId() == R.id.bt_qrc){
            Intent intent = new Intent(this, MyCaptureActivity.class);
            startActivityForResult(intent,Activity.RESULT_FIRST_USER);
        }
    }

    /**
     * 打开红外页面
     */
    public void goInfraredRemote(String appUrl){
        SharedPreferences.Editor editor = sp.edit();
        editor.putString("url",appUrl);
        editor.commit();
        Intent intent = new Intent(this, InfraredRemoteActivity.class);
        startActivity(intent);
        MainActivity.this.finish();
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, @Nullable Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (Activity.RESULT_OK == resultCode) {
            String msg = data.getStringExtra(CameraScan.SCAN_RESULT);
            Toast.makeText(this,msg, Toast.LENGTH_LONG).show();
        }
    }

    @Override
    public boolean handleMessage(@NonNull Message msg) {
        Log.d("handleMessage",msg.obj + "");
        try {
            if(msg.what == 500){
                new AlertDialog.Builder(this)
                        .setTitle(String.format("提示"))
                        .setMessage("网络连接异常，请重试")
                        .setPositiveButton("确定", (dialog, which) -> {
                            MainActivity.this.finish();
                        })
                        .setCancelable(false)
                        .create()
                        .show();
                return false;
            }
            JSONObject appData = JSON.parseObject(msg.obj.toString());
            appData = JSON.parseObject(appData.getString("data"));
            int appVersion = appData.getInteger("appVersion");
            String downLoadUrl = appData.getString("downLoadUrl");
            String appUrl = appData.getString("appUrl");
            int versionCode = getPackageManager().getPackageInfo(getPackageName(), 0).versionCode;
            if(appVersion > versionCode){
                this.updateApp(downLoadUrl,appUrl);
            }else{
                this.goInfraredRemote(appUrl);
            }
        } catch (PackageManager.NameNotFoundException e) {
            throw new RuntimeException(e);
        }
        return false;
    }

    public void updateApp(final String downLoadUrl,final String appUrl){
        new AlertDialog.Builder(this)
            .setTitle(String.format("提示"))
            .setMessage("有新版本需要更新")
            .setPositiveButton("升级", (dialog, which) -> {
                String channel = ChannelReaderUtil.getChannel(getApplicationContext());
                Uri uri = Uri.parse(String.format(downLoadUrl,channel));
                Intent it = new Intent(Intent.ACTION_VIEW,uri);
                MainActivity.this.startActivity(it);
                dialog.dismiss();
                MainActivity.this.finish();
            })
            .setNegativeButton("暂不升级", (dialog, which) -> {
                this.goInfraredRemote(appUrl);
                dialog.dismiss();
            })
            .setCancelable(false)
            .create()
            .show();
    }



}